@@ -44,13 +44,7 @@ pip install cloudcomponents.cdk-developer-tools-notifications
 ## How to use
 
 ```python
-import { Construct, Stack, StackProps } from '@aws-cdk/core';
-import { Repository } from '@aws-cdk/aws-codecommit';
-import { Pipeline, Artifact } from '@aws-cdk/aws-codepipeline';
-import {
-  CodeCommitSourceAction,
-  ManualApprovalAction,
-} from '@aws-cdk/aws-codepipeline-actions';
+import { SlackChannelConfiguration, MSTeamsIncomingWebhookConfiguration, AccountLabelMode } from '@cloudcomponents/cdk-chatops';
 import {
   RepositoryNotificationRule,
   PipelineNotificationRule,
@@ -59,11 +53,11 @@ import {
   SlackChannel,
   MSTeamsIncomingWebhook,
 } from '@cloudcomponents/cdk-developer-tools-notifications';
-import {
-  SlackChannelConfiguration,
-  MSTeamsIncomingWebhookConfiguration,
-  AccountLabelMode,
-} from '@cloudcomponents/cdk-chatops';
+import { Stack, StackProps } from 'aws-cdk-lib';
+import { Repository } from 'aws-cdk-lib/aws-codecommit';
+import { Pipeline, Artifact } from 'aws-cdk-lib/aws-codepipeline';
+import { CodeCommitSourceAction, ManualApprovalAction } from 'aws-cdk-lib/aws-codepipeline-actions';
+import { Construct } from 'constructs';
 
 export class NotificationsStack extends Stack {
   constructor(scope: Construct, id: string, props?: StackProps) {
@@ -73,34 +67,32 @@ export class NotificationsStack extends Stack {
       repositoryName: 'notifications-repository',
     });
 
+    if (typeof process.env.SLACK_WORKSPACE_ID === 'undefined') {
+      throw new Error('environment variable SLACK_WORKSPACE_ID undefined');
+    }
+    if (typeof process.env.SLACK_CHANNEL_ID === 'undefined') {
+      throw new Error('environment variable SLACK_CHANNEL_ID undefined');
+    }
     const slackChannel = new SlackChannelConfiguration(this, 'SlackChannel', {
-      slackWorkspaceId: process.env.SLACK_WORKSPACE_ID as string,
+      slackWorkspaceId: process.env.SLACK_WORKSPACE_ID,
       configurationName: 'notifications',
-      slackChannelId: process.env.SLACK_CHANNEL_ID as string,
+      slackChannelId: process.env.SLACK_CHANNEL_ID,
     });
 
-    const webhook = new MSTeamsIncomingWebhookConfiguration(
-      this,
-      'MSTeamsWebhook',
-      {
-        url: process.env.INCOMING_WEBHOOK_URL as string,
-        accountLabelMode: AccountLabelMode.ID_AND_ALIAS,
-        themeColor: '#FF0000',
-      },
-    );
+    if (typeof process.env.INCOMING_WEBHOOK_URL === 'undefined') {
+      throw new Error('environment variable INCOMING_WEBHOOK_URL undefined');
+    }
+    const webhook = new MSTeamsIncomingWebhookConfiguration(this, 'MSTeamsWebhook', {
+      url: process.env.INCOMING_WEBHOOK_URL,
+      accountLabelMode: AccountLabelMode.ID_AND_ALIAS,
+      themeColor: '#FF0000',
+    });
 
     new RepositoryNotificationRule(this, 'RepoNotifications', {
       name: 'notifications-repository',
       repository,
-      events: [
-        RepositoryEvent.COMMENTS_ON_COMMITS,
-        RepositoryEvent.PULL_REQUEST_CREATED,
-        RepositoryEvent.PULL_REQUEST_MERGED,
-      ],
-      targets: [
-        new SlackChannel(slackChannel),
-        new MSTeamsIncomingWebhook(webhook),
-      ],
+      events: [RepositoryEvent.COMMENTS_ON_COMMITS, RepositoryEvent.PULL_REQUEST_CREATED, RepositoryEvent.PULL_REQUEST_MERGED],
+      targets: [new SlackChannel(slackChannel), new MSTeamsIncomingWebhook(webhook)],
     });
 
     const sourceArtifact = new Artifact();
@@ -146,10 +138,7 @@ export class NotificationsStack extends Stack {
         // PipelineEvent.STAGE_EXECUTION_SUCCEEDED,
         // PipelineEvent.STAGE_EXECUTION_FAILED,
       ],
-      targets: [
-        new SlackChannel(slackChannel),
-        new MSTeamsIncomingWebhook(webhook),
-      ],
+      targets: [new SlackChannel(slackChannel), new MSTeamsIncomingWebhook(webhook)],
     });
   }
 }
@@ -184,8 +173,8 @@ import aws_cdk.aws_codecommit
 import aws_cdk.aws_codedeploy
 import aws_cdk.aws_codepipeline
 import aws_cdk.aws_sns
-import aws_cdk.core
 import cloudcomponents.cdk_chatops
+import constructs
 
 
 @jsii.enum(
@@ -324,7 +313,7 @@ class INotificationTarget(typing_extensions.Protocol):
     @jsii.member(jsii_name="bind")
     def bind(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         rule: INotificationRule,
     ) -> "NotificationTargetProperty":
         '''
@@ -340,7 +329,7 @@ class _INotificationTargetProxy:
     @jsii.member(jsii_name="bind")
     def bind(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         rule: INotificationRule,
     ) -> "NotificationTargetProperty":
         '''
@@ -370,7 +359,7 @@ class MSTeamsIncomingWebhook(
     @jsii.member(jsii_name="bind")
     def bind(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         _rule: INotificationRule,
     ) -> "NotificationTargetProperty":
         '''
@@ -382,13 +371,13 @@ class MSTeamsIncomingWebhook(
 
 @jsii.implements(INotificationRule)
 class NotificationRule(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cloudcomponents/cdk-developer-tools-notifications.NotificationRule",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         events: typing.Sequence[typing.Union["RepositoryEvent", "ProjectEvent", ApplicationEvent, "PipelineEvent"]],
@@ -426,15 +415,6 @@ class NotificationRule(
         '''
         return typing.cast(None, jsii.invoke(self, "addTarget", [target]))
 
-    @jsii.member(jsii_name="validate")
-    def _validate(self) -> typing.List[builtins.str]:
-        '''Validate the current construct.
-
-        This method can be implemented by derived constructs in order to perform
-        validation logic. It is called on all constructs before synthesis.
-        '''
-        return typing.cast(typing.List[builtins.str], jsii.invoke(self, "validate", []))
-
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="notificationRuleArn")
     def notification_rule_arn(self) -> builtins.str:
@@ -638,7 +618,7 @@ class PipelineNotificationRule(
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         events: typing.Sequence[PipelineEvent],
@@ -799,7 +779,7 @@ class ProjectNotificationRule(
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         events: typing.Sequence[ProjectEvent],
@@ -967,7 +947,7 @@ class RepositoryNotificationRule(
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         events: typing.Sequence[RepositoryEvent],
@@ -1128,7 +1108,7 @@ class SlackChannel(
     @jsii.member(jsii_name="bind")
     def bind(
         self,
-        _scope: aws_cdk.core.Construct,
+        _scope: constructs.Construct,
         _rule: INotificationRule,
     ) -> NotificationTargetProperty:
         '''
@@ -1152,7 +1132,7 @@ class SnsTopic(
     @jsii.member(jsii_name="bind")
     def bind(
         self,
-        _scope: aws_cdk.core.Construct,
+        _scope: constructs.Construct,
         _rule: INotificationRule,
     ) -> NotificationTargetProperty:
         '''
@@ -1181,7 +1161,7 @@ class ApplicationNotificationRule(
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         application: typing.Union[aws_cdk.aws_codedeploy.IServerApplication, aws_cdk.aws_codedeploy.ILambdaApplication, aws_cdk.aws_codedeploy.IEcsApplication],
